@@ -815,21 +815,22 @@ print("PASSED dynamic array of pointers access")
 
 # check 'tm' struct conversions
 print("checking 'tm' struct conversions ...")
-gps = 989168284
-utc = [2011, 5, 11, 16, 57, 49, 2, 131, 0]
-assert(lal.GPSToUTC(gps) == utc)
-assert(lal.UTCToGPS(utc) == gps)
-assert(lal.UTCToGPS(utc[0:6]) == gps)
-utc[6] = utc[7] = 0
-for i in [-1, 0, 1]:
-    utc[8] = i
-    assert(lal.UTCToGPS(utc) == gps)
-utcd = utc
+gps0 = 989168284
+utc0 = [2011, 5, 11, 16, 57, 49, 2, 131, 0]
+assert(lal.GPSToUTC(gps0) == tuple(utc0))
+assert(lal.UTCToGPS(utc0) == gps0)
 for i in range(0, 10):
-    utcd[2] = utc[2] + i
-    utcd = lal.GPSToUTC(lal.UTCToGPS(utcd))
-    dt = datetime.datetime(*utcd[0:6])
-    assert(utcd[6] == dt.weekday())
+    gps = gps0 + i * 86400
+    utc = list(utc0)
+    utc[2] = utc[2] + i
+    utc[6] = (utc[6] + i) % 7
+    utc[7] = utc[7] + i
+    utc[8] = -1 + (i % 3)
+    assert(lal.GPSToUTC(gps)[0:8] == tuple(utc[0:8]))
+    assert(lal.UTCToGPS(utc) == gps)
+    utc = lal.GPSToUTC(lal.UTCToGPS(utc))
+    dt = datetime.datetime(*utc[0:6])
+    assert(utc[6] == dt.weekday())
 lal.CheckMemoryLeaks()
 print("PASSED 'tm' struct conversions")
 
@@ -868,6 +869,10 @@ assert(t1 % t2 == 0.5 and isinstance(t1 % t2, LIGOTimeGPS))
 assert(t1 > t2 and t2 < t1 and t1 >= t2 and t2 <= t1)
 assert(LIGOTimeGPS(333333333,333333333) == LIGOTimeGPS(1000000000) / 3)
 assert(LIGOTimeGPS(666666666,666666667) == LIGOTimeGPS(2000000000) / 3)
+assert(LIGOTimeGPS("-62997760.825036067") == LIGOTimeGPS("-47044285.062262587") - LIGOTimeGPS("15953475.76277348"))
+assert(LIGOTimeGPS("-6542354.389038577") == LIGOTimeGPS("-914984.929117316") * 7.1502318572066237)
+assert(LIGOTimeGPS("-6542354.389038577") == 7.1502318572066237 * LIGOTimeGPS("-914984.929117316"))
+assert(LIGOTimeGPS("-127965.770535834") == LIGOTimeGPS("-914984.929117316") / 7.1502318572066237)
 t1 += 812345667.75
 assert(str(t1) == "812345678.250000000")
 assert(LIGOTimeGPS(repr(t1)) == t1)
@@ -879,6 +884,7 @@ t4struct.t = 1234.5
 assert(t4struct.t == 1234.5)
 t5 = LIGOTimeGPS("1000")
 assert(t5 == 1000)
+print("*** below should be error messages from LIGOTimeGPS constructor ***")
 try:
     t5 = LIGOTimeGPS("abc1000")
     expected_exception = True
@@ -891,6 +897,7 @@ try:
 except:
     pass
 assert(not expected_exception)
+print("*** above should be error messages from LIGOTimeGPS constructor ***")
 assert(lal.swig_lal_test_noptrgps(LIGOTimeGPS(1234.5)) == lal.swig_lal_test_noptrgps(1234.5))
 del t0
 del t1
